@@ -1,6 +1,10 @@
 import django
 from django.apps import AppConfig
-from django.utils.translation import ugettext_lazy as _
+
+if django.VERSION >= (3, 0):
+    from django.utils.translation import gettext_lazy as _
+else:
+    from django.utils.translation import ugettext_lazy as _
 
 from django_jsonfield_backport import features, forms, models
 
